CRESSP
Description: Molecular Mimicry Map of SARS-CoV-2 web application

##### Keyboard Shortcuts

##### General

Press `Ctrl` or `Cmd` + `s`(screenshot) to capture the current view and download it as a PNG file

Press `Ctrl` or `Cmd` + `i`(introduction) to toggle the modal showing file loader and instructions

Press `Ctrl` or `Cmd` + `a`(information on hover) to toggle the click/hover events of the main graph.

Press `Ctrl` or `Cmd` + `h`(help messages) to toggle tooltip messages that are shown when mouse pointers are on buttons.

Press `Ctrl` or `Cmd` + `u`(UP) to move to the top of the page.

Press `Ctrl` or `Cmd` + `d`(Down) to move to the bottom of the page.

##### Panel Control

Press `Ctrl` or `Cmd` + `b`(B-cell Cross Reactivity Pred.) to show/hide the parallel coordinates plot showing B-cell cross reactivity prediction metrics

Press `Ctrl` or `Cmd` + `g`(T-cell Cross Reactivity Pred.) to show/hide the parallel coordinates plot showing T-cell cross reactivity prediction metrics

Press `Ctrl` or `Cmd` + `t`(Table) to show/hide the DataTable panel

# File Loader

Load CRESSP Output Files
Files to load:
or Drag & Drop files here

Status:

# Usages

## Explore cross-reactive immune epitopes

Toggle help messages by pressing `Cmd` + `H`
Keyboard shorcuts can be found at the upper right corner

## Filter cross-reactive immune epitopes

Multiple filters can be applied.
To remove a filter, click the filter again

## Visualize Aligned Structures

Click a row in the aligned sequence table to highlight a pair of aligned residues on target and query structures
When protein structure is not available, a black screen will be shown

Previous Next